package com.ruoyi.szxc.service;

import com.ruoyi.szxc.domain.SzxcCsEmplyees;

import java.util.List;

/**
 * 场所员工Service接口
 * 
 * @author hs
 * @date 2024-03-28
 */
public interface ISzxcCsEmplyeesService 
{
    /**
     * 查询场所员工
     * 
     * @param id 场所员工主键
     * @return 场所员工
     */
    public SzxcCsEmplyees selectSzxcCsEmplyeesById(Long id);

    /**
     * 查询场所员工列表
     * 
     * @param szxcCsEmplyees 场所员工
     * @return 场所员工集合
     */
    public List<SzxcCsEmplyees> selectSzxcCsEmplyeesList(SzxcCsEmplyees szxcCsEmplyees);

    /**
     * 新增场所员工
     * 
     * @param szxcCsEmplyees 场所员工
     * @return 结果
     */
    public int insertSzxcCsEmplyees(SzxcCsEmplyees szxcCsEmplyees);

    /**
     * 修改场所员工
     * 
     * @param szxcCsEmplyees 场所员工
     * @return 结果
     */
    public int updateSzxcCsEmplyees(SzxcCsEmplyees szxcCsEmplyees);

    /**
     * 批量删除场所员工
     * 
     * @param ids 需要删除的场所员工主键集合
     * @return 结果
     */
    public int deleteSzxcCsEmplyeesByIds(Long[] ids);

    /**
     * 删除场所员工信息
     * 
     * @param id 场所员工主键
     * @return 结果
     */
    public int deleteSzxcCsEmplyeesById(Long id);
}
