package com.ruoyi.szxc.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.szxc.domain.SzxcCsEmplyees;
import com.ruoyi.szxc.service.ISzxcCsEmplyeesService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 场所员工Controller
 * 
 * @author hs
 * @date 2024-03-28
 */
@RestController
@RequestMapping("/szxc/emplyees")
public class SzxcCsEmplyeesController extends BaseController
{
    @Autowired
    private ISzxcCsEmplyeesService szxcCsEmplyeesService;

    /**
     * 查询场所员工列表
     */
    @PreAuthorize("@ss.hasPermi('szxc:emplyees:list')")
    @GetMapping("/list")
    public TableDataInfo list(SzxcCsEmplyees szxcCsEmplyees)
    {
        startPage();
        List<SzxcCsEmplyees> list = szxcCsEmplyeesService.selectSzxcCsEmplyeesList(szxcCsEmplyees);
        return getDataTable(list);
    }

    /**
     * 导出场所员工列表
     */
    @PreAuthorize("@ss.hasPermi('szxc:emplyees:export')")
    @Log(title = "场所员工", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SzxcCsEmplyees szxcCsEmplyees)
    {
        List<SzxcCsEmplyees> list = szxcCsEmplyeesService.selectSzxcCsEmplyeesList(szxcCsEmplyees);
        ExcelUtil<SzxcCsEmplyees> util = new ExcelUtil<SzxcCsEmplyees>(SzxcCsEmplyees.class);
        util.exportExcel(response, list, "场所员工数据");
    }

    /**
     * 获取场所员工详细信息
     */
    @PreAuthorize("@ss.hasPermi('szxc:emplyees:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(szxcCsEmplyeesService.selectSzxcCsEmplyeesById(id));
    }

    /**
     * 新增场所员工
     */
    @PreAuthorize("@ss.hasPermi('szxc:emplyees:add')")
    @Log(title = "场所员工", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SzxcCsEmplyees szxcCsEmplyees)
    {
        return toAjax(szxcCsEmplyeesService.insertSzxcCsEmplyees(szxcCsEmplyees));
    }

    /**
     * 修改场所员工
     */
    @PreAuthorize("@ss.hasPermi('szxc:emplyees:edit')")
    @Log(title = "场所员工", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SzxcCsEmplyees szxcCsEmplyees)
    {
        return toAjax(szxcCsEmplyeesService.updateSzxcCsEmplyees(szxcCsEmplyees));
    }

    /**
     * 删除场所员工
     */
    @PreAuthorize("@ss.hasPermi('szxc:emplyees:remove')")
    @Log(title = "场所员工", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(szxcCsEmplyeesService.deleteSzxcCsEmplyeesByIds(ids));
    }
}
